import re
import secrets

WORD_PATTERN = re.compile(r"(\w+)")


class BrainCell:
    """
    Main thinking mechanism.

    It decides when and what to say.
    """

    def do_i_need_to_say_something(self) -> bool:
        """
        One of the most important decisions.

        This brain cell's function looks
        deep inside the palaces of the mind,
        searching through the secrets of the universe
        and decides if she want to say something.

        :return: The decision.
        """
        return secrets.randbelow(11) < 1  # noqa: WPS432

    def create_reply(self, sentence: str) -> str:
        """
        The hardest action to accomplish.

        This brain cell function produces
        thoughtful reply to evrey sentence that
        needs it.

        :param sentence: Sentence that needs a reply.
        :return: actual reply.
        """
        tokens = WORD_PATTERN.findall(sentence)
        for token in reversed(tokens):
            token_parts = token.lower().split("да")
            if len(token_parts) > 1:
                postfix = token_parts[-1]
                break

        return f"Пизда{postfix}."
